package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.WyPlatformActivityBeer;
import com.ruoyi.system.domain.WyPlatformActivityBeerView;

/**
 * 平台活动酒款Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-06
 */
public interface WyPlatformActivityBeerMapper 
{
    /**
     * 查询平台活动酒款
     * 
     * @param activityId 平台活动酒款主键
     * @return 平台活动酒款
     */
    public List<WyPlatformActivityBeer> selectWyPlatformActivityBeerByActivityId(Long activityId);

    /**
     * 查询平台活动酒款列表
     * 
     * @param wyPlatformActivityBeer 平台活动酒款
     * @return 平台活动酒款集合
     */
    public List<WyPlatformActivityBeer> selectWyPlatformActivityBeerList(WyPlatformActivityBeer wyPlatformActivityBeer);

    public List<WyPlatformActivityBeerView> selectWyPlatformActivityBeerViewList(WyPlatformActivityBeerView wyPlatformActivityBeerView);
    /**
     * 新增平台活动酒款
     * 
     * @param wyPlatformActivityBeer 平台活动酒款
     * @return 结果
     */
    public int insertWyPlatformActivityBeer(WyPlatformActivityBeer wyPlatformActivityBeer);

    /**
     * 修改平台活动酒款
     * 
     * @param wyPlatformActivityBeer 平台活动酒款
     * @return 结果
     */
    public int updateWyPlatformActivityBeer(WyPlatformActivityBeer wyPlatformActivityBeer);

    /**
     * 删除平台活动酒款
     * 
     * @param activityId 平台活动酒款主键
     * @return 结果
     */
    public int deleteWyPlatformActivityBeerByActivityId(Long activityId);

    /**
     * 批量删除平台活动酒款
     * 
     * @param activityIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyPlatformActivityBeerByActivityIds(Long[] activityIds);
}
